%	PersonalFME - Gateway linking analog radio selcalls to internet communication services
% Copyright(C) 2010-2017 Ralf Rettig (www.personalfme.de)
%
% This program is free software: you can redistribute it and / or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.If not, see <http://www.gnu.org/licenses/>

% Plot test case results for FME-detection software

% parameters
xAxisIndex = 5;														% index of property in the parameter file to be plotted on the x-axis
yAxisIndex = 27;													% index of property in the parameter file to be plotted on the y-axis
resultIndex = 22;													% index of success flag in the result file to be plotted on the z-axis
testParamFileName = './fmeDetectionTests/testRequirements.txt';		% name of the file storing the test input data generated by the test program
testResultFileName = './fmeDetectionTests/testResults.txt';			% name of the result file generated by the test program
plotBaseName = 'testResult';										% base name of the image files containing the results (only used in case of a text-only terminal)
	
% load data skipping the header line
dataParams = dlmread( testParamFileName, '\t', 1, 0 );
dataResults = dlmread( testResultFileName, '\t', 1, 0 );

% extract parameters to be plotted
xAxis = dataParams( :,  xAxisIndex );
yAxis = dataParams( :, yAxisIndex );
result = dataResults( :, resultIndex );

% plotting
screenSize = get( 0,'ScreenSize' );
if isequal( screenSize(3:4),[1 1] )
	isOnlyText = true;
else
	isOnlyText = false;
end

if ( isOnlyText )
	set( gcf, 'visible','off' );
	figure, close
end

successPlotVar = [];
failPlotVar = [];
for i=1:size( result, 1 )
	if ( result(i) == 0 )
		failPlotVar(end+1,:) = [ xAxis(i), yAxis(i), result(i) ];
	else
		successPlotVar(end+1,:) = [ xAxis(i), yAxis(i), result(i) ];
	end
end

if ( ~isempty( failPlotVar ) )
	plot3( failPlotVar(:,1), failPlotVar(:,2), failPlotVar(:,3), '*b' );
	hold on
end
if ( ~isempty( successPlotVar ) )
	plot3( successPlotVar(:,1), successPlotVar(:,2), successPlotVar(:,3), '*r' );
end
hold off

if ( isOnlyText )
	plotFileNameBase = 'testResult';
	plotFileName = sprintf( '%s-%s.jpg', plotBaseName, strrep( datestr( clock ), ':', '-' ) );
	saveas( gcf, plotFileName, 'jpg' );
end

pause(20);