/*	PersonalFME - Gateway linking analog radio selcalls to internet communication services
Copyright(C) 2010-2017 Ralf Rettig (www.personalfme.de)

This program is free software: you can redistribute it and / or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.If not, see <http://www.gnu.org/licenses/>
*/
#pragma once
#include "StatusMessage.h"

#if defined _WIN32 || defined __CYGWIN__
	#ifdef UTILITY_API
		// All functions in this file are exported
	#else
		// All functions in this file are imported
		// Windows
		#ifdef __GNUC__
			// GCC
			#define UTILITY_API __attribute__ ((dllimport))
		#else
			// Microsoft Visual Studio
			#define UTILITY_API __declspec(dllimport)
		#endif
	#endif
#else
	// Linux
	#if __GNUC__ >= 4
		#define UTILITY_API __attribute__ ((visibility ("default")))
	#else
		#define UTILITY_API
	#endif		
#endif

/*@{*/
/** \ingroup Utilities
*/
namespace Utilities {
	namespace Message {
		/** @param DetectorStatusCode	Possible stati of a detector
		*/
		enum DetectorStatusCode { RUNNING, STOPPED };

		/**	\ingroup Utilities
		*	Class representing a status message emitted by a sequence detector
		*/
		class CDetectorStatusMessage : public CStatusMessage
		{
		public:
			UTILITY_API CDetectorStatusMessage( const boost::posix_time::ptime& messageTime, const DetectorStatusCode& status, const int& samplingFreq = 0 );
			UTILITY_API virtual void GetMessageContent( DetectorStatusCode& status, int& samplingFreq ) const;
			UTILITY_API virtual ~CDetectorStatusMessage();
		private:
			DetectorStatusCode status;
			int samplingFreq;
		};
	}
}
/*@}*/
